instrumenttools.iterate_out_of_range_notes_and_chords
=====================================================

.. autofunction:: abjad.tools.instrumenttools.iterate_out_of_range_notes_and_chords.iterate_out_of_range_notes_and_chords
